## Community Inclusion Currencies (CICs) Documentation
Community Inclusion Currency (CIC) technology seeks to give organizations and communities the ability to issue, use and manage CICs in order to build resilient and connected economies.

 ## General Documentation
 + [White Paper](https://gitlab.com/grassrootseconomics/cic-docs/-/blob/master/CIC-White-Paper.pdf)
 + [Training Materials](https://gitlab.com/grassrootseconomics/cic-docs/-/blob/master/CIC_Training_Guide_Kenya.pdf) 
 + [Frequently Asked Questions](https://docs.google.com/document/d/1qtlOEL4pqW1vOL893BaXH9OqRSAO3k0q2eWbVIkxEvU/edit?usp=sharing) 
 + [Blog](https://www.grassrootseconomics.org/blog)
 + [MOOC](https://www.grassrootseconomics.org/mooc) - Very old (paper based systems)
 + [Village Market Simulator series](https://www.youtube.com/playlist?list=PLPUExzwZAUpbEInJy_8Wj_c_mDsw7-qXe)
 + [Transaction Data CSVs](https://www.grassrootseconomics.org/research): Transaction Datasets and Research
 + [Live Data Dashboard](https://dashboard.sarafu.network)
 + [Animated Explainer Video](https://www.youtube.com/watch?v=vJL9-FFleow)
 
 
 ## Open source code
 + [Code Reposity Overview](https://gitlab.com/grassrootseconomics/cic-platform/-/wikis/BLOXBERG-component-overview)
 + [Managment Platform](https://gitlab.com/grassrootseconomics/cic-platform)
 + [Dashboard](https://github.com/GrassrootsEconomics/Accdash) [Dashboard API](https://github.com/GrassrootsEconomics/Accap)
 + [Blockchain Smart Contract](https://github.com/bancorprotocol/contracts) 

## CIC full system vision ##
 * Blockchain
   * Currently: We are on a public blockchain (Layer 2 side chain) 
   * Goal: To ensure decentralization, censor proofing and fair gas prices we look for Humanitarian Blockchains like bloxberg.org.
     * A blockchain where gas prices can be kept to zero. 
     * A Proof of Authority chain where nodes can be elected democratically.
     * A blockchain that enables easy and secure bridging to other chains. 
 * Blockchain Contracts
   * [Sarafu](https://gitlab.com/grassrootseconomics/sarafu-token) - Network / Basic Income token - Mints tokens that include a demurrage and redistribution.
   * Bridge - in order to move between the side chains (Layer 2) and the Ethereum main net we need a bridge 
     * Currently: We have no connections to Ethereum Mainnet 
     * Goal: To have options to bridge to a variety of other tokens
   * Liquidty Pools - Enable connection of Sarafu and CICs to each other and outside networks
     * Currently: Bancor Protocol v1 - [Blockchain Smart Contract](https://github.com/bancorprotocol/contracts)
   * Contract Deployment (Currency Creation service)
     * Currently: We currently deploy the Bancor Contract suite manually via Command line
     * Goal: A web based interface for organizations and communities to create their own tokens
* CIC Token Creation system 
     * Currently: Manual contract deployment (command line)
     * Goal: Registered organizations can submit an application to be an issuer, they must have:
        * an audited and legally binding backing commitment signed by local guarentors to back the total amount of a CIC .
        * The CIC issuers should also choose to add thier CIC to a liquidity pool with Sarafu or other CICs for connections
* Cloud server - is where we host all of our systems, Platform, Dashboard, future blockchain node.  
   * Currently: We are using AWS for instances and data storgage along with postgress databases - Transactions are done here first then synced with blockchain
   * Goal: Migrating servers to Digital Ocean using Kubernetes. 
     * Moving toward a web-based wallet and decentralized data storage with self-soverign data (certificate based)
 * Simulations 
   * Currently: We started with a home grown Village Market Simulator and are currently are developing and using a cadCAD based [modeling](https://gitlab.com/grassrootseconomics/cic-modeling) simulation built by BlockScience
   * Goal: To build on this simulation to validate and stress test economic models and to provide predictive analysis based on data
 * Dashboard
   * Currently: [Our dashboard](https://dashboard.sarafu.network) uses a D3 javascript we also have an internal dashboard for CIC platform administrators. 
     * We are pulling data from an internal postgres database on the CIC Mgmt Platform as well as blockchain transaction data from BlockScout
   * Goal: To have system related information available to field officers and users on Android phones and to pull data from our own blockchain node.
     * To allow donors to give directly and measure the impact of their giving
     * To visualize trade and the health of economies and communities
     * To pull transaction and user meta data from blockchain directly (also used in marketplace)
 * Marketplace
   * Currently: Word of mouth but Grassroots Economics provides limited signage to users and marketing of products in the network is done by word of mouth, SMS messaging and a phone support team.
   * Goal: A web based interface for organizations and communities to share projects, event offers and wants using CICs
     * Self-sovergin [certificates](https://gitlab.com/grassrootseconomics/cic-docs/-/blob/master/spec/020_redeemable_certifcate.md) (NFTs) form the basis for the marketplace 
     * A USSD marketplace (Directory) system that can be searchable and likned to regional areas
 * CIC Administration Dashboard (CICADA) - Management Platform 
     * Currently: System admins (GE staff) are able to assist users to reset pins, reverse transactions, create new users. The system is build on React and Flask in Python and uses postgres for data stroage.
     * Goal: Migration to Angular and stabilization of the platform and synchronization to blockchain, and eventual migration to a webBased wallet system with cloud storage with minimal need.
 * Wallet:
     * Currently: Users connect via USSD through AfricasTalking to connect with their wallet on the CIC Mgmt Platform, private keys are held by Grassroots Economics for these phones
     * Goal: 
       * [WebApp](https://gitlab.com/grassrootseconomics/cic-docs/-/blob/master/spec/010_Web_Wallet.md) 
       * Non custodial
       * Social account recovery
       * Cloud data storage (Swarm/IPFS) - opt in data, with an option for sharing and 3rd party validation
       * Market Place linkages
       * Auto-conversion – so you only have one (CIC) token (your community token) - all other tokens auto convert
       * CIC aware 
         * you can change your home token to another
         * You can see the stats of any CIC you want to trade with or change to
         * You can see the effect of converting to other tokens
 * Fiat On-ramp / off-ramp - In order to enable users and donors to interact with CICs we need a way to move fiat on and off the blockchain
   * Currently: the float account is in no way linked to blockchain and handled manually (bank transfers)
   * Goal: To create API driven liquidity pools to fiat (eMoney) 
     * To make credit card another other payment on and offramps available and streamline our fiat to token processes.
     * Exchange Rates will be variable based on the CIC → KSH rate (depends on the liquidity pool maths) 
 * Blockchain interaction (once bridged)
   * Anyone who can obtain or create any CIC token can send it to a liquidity pool if avalaible for conversion and bridging. 
 * ID System - 
   * Currently: Each user has a sim card and the Telecom provides KYC services - users are asked a pin number to access the account on USSD 
   * Goal: Creating a more robust ID system for users with and without sim cards. Possibly adding brightID social ID  - like technologies with confidence scoring or 3rd party biometrics
     * Non custodial data ownership on cloud where users can specify what data tehy want to make avalible
 * Rewards and Incentives
     * Currently: These incentive systems are a mixture of manual and CIC Mgmt Platform base, such as initial user air drop, referral bonuses and holding fees.
     * Currently: We are using a CIC by the name of Sarafu that is not backed by anything. Users get a Sarafu for free and groups will be able to create their own CICs backed by local goods and services and connect to eachother.
     * Goal: Any org developing a CIC can easily establish various rules and policies - these should be built into the token contracts.
 * Training Materials:
   * Currently: We have minimal documentation curriculum, games and materials for training communities and CIC issuers 
   * Goal: Better curriculum and verious multi-media materials
    
 
